? sys/sys/ktrace.out
Index: sys/sys/fstypes.h
===================================================================
RCS file: /cvsroot/src/sys/sys/fstypes.h,v
retrieving revision 1.40
diff -u -p -u -r1.40 fstypes.h
--- sys/sys/fstypes.h	5 Jul 2020 20:41:50 -0000	1.40
+++ sys/sys/fstypes.h	17 Sep 2021 17:09:23 -0000
@@ -94,7 +94,7 @@ typedef struct fhandle	fhandle_t;
 #define	MNT_NOCOREDUMP	0x00008000	/* don't write core dumps to this FS */
 #define	MNT_RELATIME	0x00020000	/* only update access time if mod/ch */
 #define	MNT_IGNORE	0x00100000	/* don't show entry in df */
-#define	MNT_ACLS	0x00200000	/* uses Access Control Lists */
+#define	MNT_NFS4ACLS	0x00200000	/* uses NFS4 Access Control Lists */
 #define	MNT_DISCARD	0x00800000	/* use DISCARD/TRIM if supported */
 #define	MNT_EXTATTR	0x01000000	/* enable extended attributes */
 #define	MNT_LOG		0x02000000	/* Use logging */
@@ -104,12 +104,14 @@ typedef struct fhandle	fhandle_t;
 #define	MNT_NODEVMTIME	0x40000000	/* Never update mod times for devs */
 #define	MNT_SOFTDEP	0x80000000	/* Use soft dependencies */
 #define	MNT_POSIX1EACLS	0x00000800	/* shared with EXKERB */
+#define	MNT_ACLS	MNT_POSIX1EACLS	/* synonym */
 
 #define	__MNT_BASIC_FLAGS \
 	{ MNT_ASYNC,		0,	"asynchronous" }, \
 	{ MNT_AUTOMOUNTED,	0,	"automounted" }, \
-	{ MNT_ACLS,		0,	"acls" }, \
+	{ MNT_NFS4ACLS,		0,	"nfs4acls" }, \
 	{ MNT_POSIX1EACLS,	0,	"posix1eacls" }, \
+	{ MNT_ACLS,		0,	"acls" }, \
 	{ MNT_DISCARD,		0,	"discard" }, \
 	{ MNT_EXTATTR,		0,	"extattr" }, \
 	{ MNT_IGNORE,		0,	"hidden" }, \
@@ -130,7 +132,7 @@ typedef struct fhandle	fhandle_t;
 #define MNT_BASIC_FLAGS (MNT_ASYNC | MNT_AUTOMOUNTED | MNT_DISCARD | \
     MNT_EXTATTR | MNT_LOG | MNT_NOATIME | MNT_NOCOREDUMP | MNT_NODEV | \
     MNT_NODEVMTIME | MNT_NOEXEC | MNT_NOSUID | MNT_RDONLY | MNT_RELATIME | \
-    MNT_SOFTDEP | MNT_SYMPERM | MNT_SYNCHRONOUS | MNT_UNION | MNT_ACLS | \
+    MNT_SOFTDEP | MNT_SYMPERM | MNT_SYNCHRONOUS | MNT_UNION | MNT_NFS4ACLS | \
     MNT_POSIX1EACLS)
 /*
  * exported mount flags.
@@ -174,7 +176,7 @@ typedef struct fhandle	fhandle_t;
      MNT_NOSUID | \
      MNT_NODEV | \
      MNT_UNION | \
-     MNT_ACLS | \
+     MNT_NFS4ACLS | \
      MNT_ASYNC | \
      MNT_NOCOREDUMP | \
      MNT_IGNORE | \
Index: sys/ufs/ffs/ffs_vfsops.c
===================================================================
RCS file: /cvsroot/src/sys/ufs/ffs/ffs_vfsops.c,v
retrieving revision 1.372
diff -u -p -u -r1.372 ffs_vfsops.c
--- sys/ufs/ffs/ffs_vfsops.c	20 Aug 2020 20:28:13 -0000	1.372
+++ sys/ufs/ffs/ffs_vfsops.c	17 Sep 2021 17:09:23 -0000
@@ -398,14 +398,14 @@ ffs_mountroot(void)
 static void
 ffs_acls(struct mount *mp, int fs_flags)
 {
-	if ((fs_flags & FS_ACLS) != 0) {
+	if ((fs_flags & FS_NFS4ACLS) != 0) {
 #ifdef UFS_ACL
 		if (mp->mnt_flag & MNT_POSIX1EACLS)
 			printf("WARNING: %s: ACLs flag on fs conflicts with "
 			    "\"posix1eacls\" mount option; option ignored\n",
 			    mp->mnt_stat.f_mntonname);
 		mp->mnt_flag &= ~MNT_POSIX1EACLS;
-		mp->mnt_flag |= MNT_ACLS;
+		mp->mnt_flag |= MNT_NFS4ACLS;
 
 #else
 		printf("WARNING: %s: ACLs flag on fs but no ACLs support\n",
@@ -414,11 +414,11 @@ ffs_acls(struct mount *mp, int fs_flags)
 	}
 	if ((fs_flags & FS_POSIX1EACLS) != 0) {
 #ifdef UFS_ACL
-		if (mp->mnt_flag & MNT_ACLS)
+		if (mp->mnt_flag & MNT_NFS4ACLS)
 			printf("WARNING: %s: NFSv4 ACLs flag on fs conflicts "
 			    "with \"acls\" mount option; option ignored\n",
 			    mp->mnt_stat.f_mntonname);
-		mp->mnt_flag &= ~MNT_ACLS;
+		mp->mnt_flag &= ~MNT_NFS4ACLS;
 		mp->mnt_flag |= MNT_POSIX1EACLS;
 #else
 		printf("WARNING: %s: POSIX.1e ACLs flag on fs but no "
@@ -426,8 +426,8 @@ ffs_acls(struct mount *mp, int fs_flags)
 #endif
 	}
 
-	if ((mp->mnt_flag & (MNT_ACLS | MNT_POSIX1EACLS))
-	    == (MNT_ACLS | MNT_POSIX1EACLS))
+	if ((mp->mnt_flag & (MNT_NFS4ACLS | MNT_POSIX1EACLS))
+	    == (MNT_NFS4ACLS | MNT_POSIX1EACLS))
 	{
 		printf("WARNING: %s: posix1eacl conflicts "
 		    "with \"acls\" mount option; option ignored\n",
@@ -435,7 +435,7 @@ ffs_acls(struct mount *mp, int fs_flags)
 		mp->mnt_flag &= ~MNT_POSIX1EACLS;
 	}
 
-	if (mp->mnt_flag & (MNT_ACLS | MNT_POSIX1EACLS))
+	if (mp->mnt_flag & (MNT_NFS4ACLS | MNT_POSIX1EACLS))
 		mp->mnt_iflag &= ~(IMNT_SHRLOOKUP|IMNT_NCLOOKUP);
 	else
 		mp->mnt_iflag |= IMNT_SHRLOOKUP|IMNT_NCLOOKUP;
Index: sbin/tunefs/tunefs.c
===================================================================
RCS file: /cvsroot/src/sbin/tunefs/tunefs.c,v
retrieving revision 1.54
diff -u -p -u -r1.54 tunefs.c
--- sbin/tunefs/tunefs.c	26 Nov 2020 02:06:01 -0000	1.54
+++ sbin/tunefs/tunefs.c	17 Sep 2021 17:09:23 -0000
@@ -361,21 +361,21 @@ main(int argc, char *argv[])
 	if (aflag) {
 		name = "ACLs";
 		if (strcmp(avalue, "enable") == 0) {
-			if (sblock.fs_flags & FS_ACLS) {
+			if (sblock.fs_flags & FS_NFS4ACLS) {
 				warnx("%s remains unchanged as enabled", name);
 			} else if (sblock.fs_flags & FS_POSIX1EACLS) {
 				warnx("%s and POSIX.1e ACLs are mutually "
 				    "exclusive", name);
 			} else {
-				sblock.fs_flags |= FS_ACLS;
+				sblock.fs_flags |= FS_NFS4ACLS;
 				printf("%s set\n", name);
 			}
 		} else if (strcmp(avalue, "disable") == 0) {
-			if ((~sblock.fs_flags & FS_ACLS) == FS_ACLS) {
+			if ((~sblock.fs_flags & FS_NFS4ACLS) == FS_NFS4ACLS) {
 				warnx("%s remains unchanged as disabled",
 				    name);
 			} else {
-				sblock.fs_flags &= ~FS_ACLS;
+				sblock.fs_flags &= ~FS_NFS4ACLS;
 				printf("%s cleared\n", name);
 			}
  		}
@@ -386,7 +386,7 @@ main(int argc, char *argv[])
 		if (strcmp(pvalue, "enable") == 0) {
 			if (sblock.fs_flags & FS_POSIX1EACLS) {
 				warnx("%s remains unchanged as enabled", name);
-			} else if (sblock.fs_flags & FS_ACLS) {
+			} else if (sblock.fs_flags & FS_NFS4ACLS) {
 				warnx("%s and ACLs are mutually "
 				    "exclusive", name);
 			} else {
@@ -434,8 +434,8 @@ main(int argc, char *argv[])
 		}
 		printf("\tPOSIX.1e ACLs %s\n",
 		    (sblock.fs_flags & FS_POSIX1EACLS) ? "enabled" : "disabled");
-		printf("\tACLs %s\n",
-		    (sblock.fs_flags & FS_ACLS) ? "enabled" : "disabled");
+		printf("\tNFS4 ACLs %s\n",
+		    (sblock.fs_flags & FS_NFS4ACLS) ? "enabled" : "disabled");
 		printf("%s: no changes made\n", getprogname());
 		return 0;
 	}
Index: usr.sbin/dumpfs/dumpfs.c
===================================================================
RCS file: /cvsroot/src/usr.sbin/dumpfs/dumpfs.c,v
retrieving revision 1.64
diff -u -p -u -r1.64 dumpfs.c
--- usr.sbin/dumpfs/dumpfs.c	6 Mar 2018 07:45:38 -0000	1.64
+++ usr.sbin/dumpfs/dumpfs.c	17 Sep 2021 17:09:23 -0000
@@ -419,8 +419,10 @@ print_superblock(struct fs *fs, uint16_t
 		printf("needs fsck run ");
 	if (fs->fs_flags & FS_SUJ)
 		printf("journaled soft-updates ");
-	if (fs->fs_flags & FS_ACLS)
-		printf("acls ");
+	if (fs->fs_flags & FS_POSIX1EACLS)
+		printf("posix1e acls ");
+	if (fs->fs_flags & FS_NFS4ACLS)
+		printf("nfs4 acls ");
 	if (fs->fs_flags & FS_MULTILABEL)
 		printf("multilabel ");
 	if (fs->fs_flags & FS_GJOURNAL)
@@ -434,8 +436,9 @@ print_superblock(struct fs *fs, uint16_t
 	if (fs->fs_flags & FS_TRIM)
 		printf("trim ");
 	fsflags = fs->fs_flags & ~(FS_UNCLEAN | FS_DOSOFTDEP | FS_NEEDSFSCK |
-			FS_SUJ | FS_ACLS | FS_MULTILABEL | FS_GJOURNAL |
-			FS_FLAGS_UPDATED | FS_DOWAPBL | FS_DOQUOTA2 | FS_TRIM);
+			FS_SUJ | FS_POSIX1EACLS | FS_MULTILABEL | FS_GJOURNAL |
+			FS_NFS4ACLS | FS_FLAGS_UPDATED | FS_DOWAPBL |
+			FS_DOQUOTA2 | FS_TRIM);
 #ifdef FS_INDEXDIRS
 	if (fs->fs_flags & FS_INDEXDIRS)
 		printf("indexed directories ");
@@ -444,35 +447,38 @@ print_superblock(struct fs *fs, uint16_t
 	if (fsflags != 0)
 		printf("unknown flags (%#x)", fsflags);
 	printf("\nfsmnt\t%s\n", fs->fs_fsmnt);
-	if (!printold)
+	if (!printold) {
 		printf("volname\t%s\tswuid\t%ju\n",
 		    fs->fs_volname, (uintmax_t)fs->fs_swuid);
-	if (printold) {
-		if (fs->fs_old_cpc != 0)
-			printf("blocks available in each of %d rotational "
-			       "positions\n", fs->fs_old_nrpos);
-		else
-			printf("(no rotational position table)\n\n");
-		if (ISOPT(opt_verbose)) {
-			int c, j, k;
-			for (c = 0; c < fs->fs_old_cpc; c++) {
-				printf("cylinder number %d:", c);
-				for (i = 0; i < fs->fs_old_nrpos; i++) {
-					if (old_fs_postbl(&afs, c, opostbl)[i] == -1)
-						continue;
-					printf("\n   position %d:\t", i);
-					for (j = old_fs_postbl(&afs, c, opostbl)[i], k = 1; ;
-							 j += old_fs_rotbl(&afs)[j], k++) {
-						printf("%5d", j);
-						if (k % 12 == 0)
-							printf("\n\t\t");
-						if (old_fs_rotbl(&afs)[j] == 0)
-							break;
-					}
-				}
-				printf("\n");
+		return 0;
+	}
+
+	if (fs->fs_old_cpc != 0)
+		printf("blocks available in each of %d rotational "
+		       "positions\n", fs->fs_old_nrpos);
+	else
+		printf("(no rotational position table)\n\n");
+
+	if (!ISOPT(opt_verbose)) {
+		return 0;
+	}
+
+	for (int c = 0; c < fs->fs_old_cpc; c++) {
+		printf("cylinder number %d:", c);
+		for (i = 0; i < fs->fs_old_nrpos; i++) {
+			if (old_fs_postbl(&afs, c, opostbl)[i] == -1)
+				continue;
+			printf("\n   position %d:\t", i);
+			for (int j = old_fs_postbl(&afs, c, opostbl)[i], k = 1;
+			    ; j += old_fs_rotbl(&afs)[j], k++) {
+				printf("%5d", j);
+				if (k % 12 == 0)
+					printf("\n\t\t");
+				if (old_fs_rotbl(&afs)[j] == 0)
+					break;
 			}
 		}
+		printf("\n");
 	}
 
 	return 0;
Index: sys/ufs/ffs/fs.h
===================================================================
RCS file: /cvsroot/src/sys/ufs/ffs/fs.h,v
retrieving revision 1.68
diff -u -p -u -r1.68 fs.h
--- sys/ufs/ffs/fs.h	16 May 2020 18:31:53 -0000	1.68
+++ sys/ufs/ffs/fs.h	17 Sep 2021 17:09:23 -0000
@@ -422,7 +422,7 @@ struct fs {
  * FS_POSIX1EACLS indicates that POSIX.1e ACLs are administratively enabled
  * for the file system, so they should be loaded from extended attributes,
  * observed for access control purposes, and be administered by object
  * owners.  FS_ACLS indicates that NFSv4 ACLs are administratively
  * enabled.  This flag is mutually exclusive with FS_POSIX1EACLS.
  */
 #define	FS_UNCLEAN	0x001	/* file system not clean at mount (unused) */
@@ -430,6 +430,7 @@ struct fs {
 #define	FS_NEEDSFSCK	0x004	/* needs sync fsck (FreeBSD compat, unused) */
 #define	FS_SUJ		0x008	/* file system using journaled softupdates */
 #define	FS_POSIX1EACLS	0x010	/* file system has POSIX.1e ACLs enabled */
+#define	FS_ACLS		FS_POSIX1EACLS	/* alias */
 #define	FS_MULTILABEL	0x020	/* file system is MAC multi-label */
 #define	FS_GJOURNAL	0x40	/* gjournaled file system */
 #define	FS_FLAGS_UPDATED 0x80	/* flags have been moved to new location */
@@ -438,11 +439,11 @@ struct fs {
 #define	FS_DOQUOTA2	0x200	/* in-filesystem quotas */
 /*     	FS_INDEXDIRS	0x200	   kernel supports indexed directories (FBSD)*/
 #define	FS_TRIM		0x400	/* discard deleted blocks in storage layer */
-#define FS_ACLS		0x800	/* file system has NFSv4 ACLs enabled */
+#define FS_NFS4ACLS	0x800	/* file system has NFSv4 ACLs enabled */
 
 /* File system flags that are ok for NetBSD if set in fs_flags */
 #define	FS_KNOWN_FLAGS	(FS_DOSOFTDEP | FS_DOWAPBL | FS_DOQUOTA2 | \
-	FS_POSIX1EACLS | FS_ACLS)
+	FS_POSIX1EACLS | FS_NFS4ACLS)
 
 /*
  * File system internal flags, also in fs_flags.
@@ -422,7 +422,7 @@ struct fs {
  * for the file system, so they should be loaded from extended attributes,
  * observed for access control purposes, and be administered by object
- * owners.  FS_ACLS indicates that NFSv4 ACLs are administratively
+ * owners.  FS_NFS4ACLS indicates that NFSv4 ACLs are administratively
  * enabled.  This flag is mutually exclusive with FS_POSIX1EACLS.
  */